summaryrefslogtreecommitdiffstats
path: root/akregator/src/feed.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/feed.cpp')
-rw-r--r--akregator/src/feed.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/akregator/src/feed.cpp b/akregator/src/feed.cpp
index 8e0c4c90..2188b384 100644
--- a/akregator/src/feed.cpp
+++ b/akregator/src/feed.cpp
@@ -87,7 +87,7 @@ class Feed::FeedPrivate
/** caches guids of tagged articles. key: tag, value: list of guids */
TQMap<TQString, TQStringList> taggedArticles;
/** list of deleted articles. This tqcontains **/
TQValueList<Article> deletedArticles;
/** caches guids of deleted articles for notification */
@@ -450,7 +450,7 @@ void Feed::appendArticles(const RSS::Document &doc)
for (it = d_articles.begin(); it != en; ++it)
{
- if ( !d->articles.tqcontains((*it).guid()) ) // article not in list
+ if ( !d->articles.contains((*it).guid()) ) // article not in list
{
Article mya(*it, this);
mya.offsetPubDate(nudge);
@@ -535,7 +535,7 @@ void Feed::appendArticle(const Article& a)
{
if ( (a.keep() && Settings::doNotExpireImportantArticles()) || ( !usesExpiryByAge() || !isExpired(a) ) ) // if not expired
{
- if (!d->articles.tqcontains(a.guid()))
+ if (!d->articles.contains(a.guid()))
{
d->articles[a.guid()] = a;
if (!a.isDeleted() && a.status() != Article::Read)
@@ -726,10 +726,10 @@ void Feed::setUnread(int unread)
void Feed::setArticleDeleted(Article& a)
{
- if (!d->deletedArticles.tqcontains(a))
+ if (!d->deletedArticles.contains(a))
d->deletedArticles.append(a);
- if (!d->removedArticlesNotify.tqcontains(a))
+ if (!d->removedArticlesNotify.contains(a))
d->removedArticlesNotify.append(a);
articlesModified();
@@ -87,7 +87,7 @@ class Feed::FeedPrivate
/** caches guids of tagged articles. key: tag, value: list of guids */
TQMap<TQString, TQStringList> taggedArticles;
- /** list of deleted articles. This tqcontains **/
+ /** list of deleted articles. This contains **/
TQValueList<Article> deletedArticles;
/** caches guids of deleted articles for notification */